@@ -17,7 +17,7 @@ use Mail::Header;
 use vars qw($VERSION);
 
 BEGIN {
-    $VERSION = "1.59";
+    $VERSION = "1.61";
     *AUTOLOAD = \&AutoLoader::AUTOLOAD;
 
     unless(defined &UNIVERSAL::isa) {
@@ -748,9 +748,10 @@ Mail::Internet - manipulate Internet format (RFC 822) mail messages
 This package provides a class object which can be used for reading, creating,
 manipulating and writing a message with RFC822 compliant headers.
 
-If you start writing a new application, you may want to use the
+If you start writing a B<new application>, you may want to use the
 L<Mail::Box> set of packages (requires perl 5.6.1), which has more
-features.  See http://perl.overmeer.net/mailbox.
+features and handles modern messages much better.
+See L<http://perl.overmeer.net/mailbox/>.
 
 =head1 CONSTRUCTOR
 
